@@ -41,6 +41,7 @@ inline uint qHash( FieldPos pos )
 
 KLinesScene::KLinesScene( QObject* parent )
     : QGraphicsScene(parent),
+      m_randomSeq(QRandomGenerator::global()->generate()),
       m_playFieldBorderSize(0), m_numFreeCells(FIELD_SIZE*FIELD_SIZE),
       m_score(0), m_bonusScore(0), m_cellSize(32), m_previewZoneVisible(true)
 {
@@ -83,9 +84,8 @@ void KLinesScene::startNewGame()
     m_popupItem->forceHide();
 
     // remove all ball items from the scene leaving other items untouched
-    QList<QGraphicsItem*> itemlist = items();
-    foreach( QGraphicsItem* item, itemlist )
-    {
+    const QList<QGraphicsItem*> itemlist = items();
+    for (QGraphicsItem* item : itemlist) {
         BallItem* ball = qgraphicsitem_cast<BallItem*>(item);
         if( ball )
         {
@@ -102,11 +102,11 @@ void KLinesScene::startNewGame()
     for(int i=0; i<3; i++)
     {
         // random color
-        BallColor c = static_cast<BallColor>(m_randomSeq.getLong(static_cast<int>(NumColors)));
+        BallColor c = static_cast<BallColor>(m_randomSeq.bounded(static_cast<int>(NumColors)));
         m_nextColors.append(c);
     }
 
-    emit stateChanged(QStringLiteral( "not_undoable" ));
+    Q_EMIT stateChanged(QStringLiteral( "not_undoable" ));
 
     nextThreeBalls();
 }
@@ -210,7 +210,7 @@ void KLinesScene::nextThreeBalls()
     for(int i=0; i<3; i++)
     {
         // random color
-        BallColor c = static_cast<BallColor>(m_randomSeq.getLong(static_cast<int>(NumColors)));
+        BallColor c = static_cast<BallColor>(m_randomSeq.bounded(static_cast<int>(NumColors)));
         m_nextColors[i] = c;
     }
 
@@ -246,8 +246,8 @@ BallItem* KLinesScene::randomlyPlaceBall(BallColor c)
     // let's find random free cell
     do
     {
-        posx = m_randomSeq.getLong(FIELD_SIZE);
-        posy = m_randomSeq.getLong(FIELD_SIZE);
+        posx = m_randomSeq.bounded(FIELD_SIZE);
+        posy = m_randomSeq.bounded(FIELD_SIZE);
     } while( m_field[posx][posy] != nullptr );
 
     BallItem* newBall = new BallItem( this);
@@ -364,15 +364,14 @@ void KLinesScene::removeAnimFinished()
             m_score += m_bonusScore;
         }
 
-        foreach( BallItem* item, m_itemsToDelete )
-        {
+        for (BallItem* item : qAsConst(m_itemsToDelete)) {
             removeItem(item);
             delete item;
         }
         m_itemsToDelete.clear();
 
         if(numBallsErased)
-            emit scoreChanged(m_score);
+            Q_EMIT scoreChanged(m_score);
     }
 }
 
@@ -512,8 +511,7 @@ void KLinesScene::searchAndErase()
                 continue;
         }
 
-    foreach( const FieldPos& pos, positionsToDelete )
-    {
+    for (const FieldPos& pos : qAsConst(positionsToDelete)) {
         m_itemsToDelete.append(m_field[pos.x][pos.y]);
         m_field[pos.x][pos.y] = nullptr;
         m_numFreeCells++;
@@ -609,7 +607,7 @@ void KLinesScene::saveUndoInfo()
     m_undoInfo.score = m_score;
     m_undoInfo.nextColors = m_nextColors;
 
-    emit stateChanged(QStringLiteral( "undoable" ));
+    Q_EMIT stateChanged(QStringLiteral( "undoable" ));
 }
 
 // Brings m_field and some other vars to the state it was before last turn
@@ -662,9 +660,9 @@ void KLinesScene::undo()
 
     m_previewItem->setPreviewColors( m_nextColors );
 
-    emit scoreChanged(m_score);
+    Q_EMIT scoreChanged(m_score);
 
-    emit stateChanged(QStringLiteral( "not_undoable" ));
+    Q_EMIT stateChanged(QStringLiteral( "not_undoable" ));
 }
 
 void KLinesScene::drawBackground(QPainter *p, const QRectF&)
@@ -690,9 +688,9 @@ void KLinesScene::gameOverHandler()
         return; // don't emit twice
     m_gameOver = true;
     qCDebug(KLINES_LOG) << "GAME OVER";
-    emit stateChanged(QStringLiteral( "not_undoable" ));
-    //emit enableUndo(false);
-    emit gameOver(m_score);
+    Q_EMIT stateChanged(QStringLiteral( "not_undoable" ));
+    //Q_EMIT enableUndo(false);
+    Q_EMIT gameOver(m_score);
 
     // disable auto-hide
     m_popupItem->setMessageTimeout(0);
